"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormattingSelector = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const ide_overlay_1 = require("@opensumi/ide-overlay");
const format_1 = require("@opensumi/monaco-editor-core/esm/vs/editor/contrib/format/browser/format");
const types_1 = require("../doc-model/types");
const preferedFormatter = 'editor.preferredFormatter';
let FormattingSelector = class FormattingSelector {
    async selectFormatter(formatters, document, mode, _kind) {
        const docRef = this.modelService.getModelReference(ide_core_browser_1.URI.from(document.uri.toJSON()));
        if (!docRef) {
            return;
        }
        const languageId = docRef.instance.languageId;
        docRef.dispose();
        const preferred = this.getPreferedFormatter(languageId);
        const elements = {};
        formatters.forEach((provider) => {
            if (provider.extensionId) {
                elements[provider.extensionId] = provider;
            }
        });
        if (preferred) {
            if (elements[preferred]) {
                return elements[preferred];
            }
            else {
                this.messageService.error((0, ide_core_browser_1.formatLocalize)('editor.format.preferredFormatterNotFound', preferred, languageId));
            }
        }
        if (formatters.length === 1) {
            return formatters[0];
        }
        if (mode === format_1.FormattingMode.Explicit) {
            const { selected, value } = await this.doPick(elements);
            if (value) {
                this.savePreferredFormatter(languageId, selected);
                return elements[selected];
            }
        }
        else {
            return undefined;
        }
    }
    async doPick(elements) {
        const showItems = Object.keys(elements).map((k) => ({
            label: elements[k].displayName,
            value: elements[k].extensionId,
        }));
        const selected = await this.quickPickService.show(showItems, {
            placeholder: (0, ide_core_browser_1.localize)('editor.format.chooseFormatter'),
        });
        if (selected) {
            return {
                selected,
                value: elements[selected],
            };
        }
        return {};
    }
    getPreferedFormatter(languageId) {
        const config = this.preferenceService.get(preferedFormatter) || {};
        return config[languageId];
    }
    async savePreferredFormatter(languageId, formatterId) {
        const config = this.preferenceService.get(preferedFormatter) || {};
        this.preferenceService.set(preferedFormatter, Object.assign(Object.assign({}, config), { [languageId]: formatterId }), ide_core_browser_1.PreferenceScope.User);
    }
    async pickFormatter(formatters, document) {
        const docRef = this.modelService.getModelReference(ide_core_browser_1.URI.from(document.uri.toJSON()));
        if (!docRef) {
            return;
        }
        const languageId = docRef.instance.languageId;
        docRef.dispose();
        const elements = {};
        formatters.forEach((provider) => {
            if (provider.extensionId) {
                elements[provider.extensionId] = provider;
            }
        });
        const { selected, value } = await this.doPick(elements);
        if (value) {
            this.savePreferredFormatter(languageId, selected);
            return value;
        }
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.QuickPickService),
    tslib_1.__metadata("design:type", Object)
], FormattingSelector.prototype, "quickPickService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.PreferenceService),
    tslib_1.__metadata("design:type", Object)
], FormattingSelector.prototype, "preferenceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(types_1.IEditorDocumentModelService),
    tslib_1.__metadata("design:type", Object)
], FormattingSelector.prototype, "modelService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_overlay_1.IMessageService),
    tslib_1.__metadata("design:type", Object)
], FormattingSelector.prototype, "messageService", void 0);
FormattingSelector = tslib_1.__decorate([
    (0, di_1.Injectable)()
], FormattingSelector);
exports.FormattingSelector = FormattingSelector;
//# sourceMappingURL=formatter-selector.js.map