"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MergeEditorFloatComponents = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const git_1 = require("@opensumi/ide-core-common/lib/commands/git");
const useEditor_1 = require("../hooks/useEditor");
const useInMergeChanges_1 = require("../hooks/useInMergeChanges");
const merge_conflict_1 = require("../merge-conflict");
const merge_editor_module_less_1 = tslib_1.__importDefault(require("./merge-editor.module.less"));
const MergeEditorFloatComponents = ({ resource }) => {
    const aiNativeConfigService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.AINativeConfigService);
    const commandService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.CommandService);
    const commandRegistry = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.CommandRegistry);
    const mergeConflictParser = (0, ide_core_browser_1.useInjectable)(merge_conflict_1.MergeConflictParser);
    const editorModel = (0, useEditor_1.useEditorDocumentModelRef)(resource.uri);
    const [isVisiable, setIsVisiable] = (0, react_1.useState)(false);
    const [conflicts, setConflicts] = (0, react_1.useState)([]);
    const inMergeChanges = (0, useInMergeChanges_1.useInMergeChanges)(resource.uri.toString());
    (0, react_1.useEffect)(() => {
        const disposables = new ide_core_browser_1.DisposableStore();
        if (editorModel) {
            const { instance } = editorModel;
            const run = () => {
                const conflicts = mergeConflictParser.scanDocument(instance.getMonacoModel());
                if (conflicts.length > 0) {
                    setIsVisiable(true);
                    setConflicts(conflicts);
                }
                else {
                    setIsVisiable(false);
                    setConflicts([]);
                }
            };
            disposables.add(editorModel.instance.getMonacoModel().onDidChangeContent(() => {
                run();
            }));
            run();
            return () => {
                disposables.dispose();
            };
        }
    }, [editorModel]);
    const [isAIResolving, setIsAIResolving] = (0, react_1.useState)(false);
    const handleOpenMergeEditor = (0, react_1.useCallback)(async () => {
        const { uri } = resource;
        [ide_core_browser_1.SCM_COMMANDS.GIT_OPEN_MERGE_EDITOR, ide_core_browser_1.SCM_COMMANDS._GIT_OPEN_MERGE_EDITOR].forEach(({ id: command }) => {
            if (commandRegistry.getCommand(command) && commandRegistry.isEnabled(command)) {
                commandService.executeCommand(command, uri);
            }
        });
    }, [resource]);
    const isSupportAIResolve = (0, react_1.useCallback)(() => aiNativeConfigService.capabilities.supportsConflictResolve, [aiNativeConfigService]);
    const handlePrev = (0, react_1.useCallback)(() => {
        commandService.tryExecuteCommand(git_1.MergeConflictCommands.Previous).then(() => {
            // TODO: 编辑器向上滚动一行
        });
    }, []);
    const handleNext = (0, react_1.useCallback)(() => {
        commandService.tryExecuteCommand(git_1.MergeConflictCommands.Next).then(() => {
            // TODO: 编辑器向上滚动一行
        });
    }, []);
    const handleAIResolve = (0, react_1.useCallback)(async () => {
        setIsAIResolving(true);
        if (isAIResolving) {
            await commandService.executeCommand(ide_core_browser_1.MERGE_CONFLICT_COMMANDS.AI_ALL_ACCEPT_STOP.id, resource.uri);
        }
        else {
            await commandService.executeCommand(ide_core_browser_1.MERGE_CONFLICT_COMMANDS.AI_ALL_ACCEPT.id, resource.uri);
        }
        setIsAIResolving(false);
    }, [resource, isAIResolving]);
    const handleReset = (0, react_1.useCallback)(() => {
        commandService.executeCommand(ide_core_browser_1.MERGE_CONFLICT_COMMANDS.ALL_RESET.id, resource.uri);
    }, [resource]);
    if (!isVisiable) {
        return null;
    }
    return (react_1.default.createElement("div", { className: merge_editor_module_less_1.default.merge_editor_float_container },
        react_1.default.createElement("div", { className: merge_editor_module_less_1.default.merge_editor_float_container_info }, (0, ide_core_common_1.formatLocalize)('merge-conflicts.merge.conflict.remain', conflicts.length)),
        react_1.default.createElement("div", { className: merge_editor_module_less_1.default.merge_editor_float_container_operation_bar },
            react_1.default.createElement("div", { id: 'merge.editor.action.button.nav' },
                react_1.default.createElement(ide_components_1.Button, { className: merge_editor_module_less_1.default.merge_conflict_bottom_btn, size: 'default', onClick: handlePrev },
                    react_1.default.createElement(ide_components_1.Icon, { icon: 'left' }),
                    react_1.default.createElement("span", null, (0, ide_core_browser_1.localize)('mergeEditor.conflict.prev'))),
                react_1.default.createElement(ide_components_1.Button, { className: merge_editor_module_less_1.default.merge_conflict_bottom_btn, size: 'default', onClick: handleNext },
                    react_1.default.createElement("span", null, (0, ide_core_browser_1.localize)('mergeEditor.conflict.next')),
                    react_1.default.createElement(ide_components_1.Icon, { icon: 'right' }))),
            react_1.default.createElement("span", { className: merge_editor_module_less_1.default.line_vertical }),
            inMergeChanges && (react_1.default.createElement(ide_components_1.Button, { id: 'merge.editor.open.tradition', className: merge_editor_module_less_1.default.merge_conflict_bottom_btn, size: 'default', onClick: handleOpenMergeEditor },
                react_1.default.createElement(ide_components_1.Icon, { icon: 'swap' }),
                react_1.default.createElement("span", null, (0, ide_core_browser_1.localize)('mergeEditor.open.3way')))),
            react_1.default.createElement(ide_components_1.Button, { id: 'merge.editor.rest', className: merge_editor_module_less_1.default.merge_conflict_bottom_btn, size: 'default', onClick: handleReset },
                react_1.default.createElement(ide_components_1.Icon, { icon: 'discard' }),
                react_1.default.createElement("span", null, (0, ide_core_browser_1.localize)('mergeEditor.reset'))),
            isSupportAIResolve() && (react_1.default.createElement(ide_components_1.Button, { id: 'merge.editor.conflict.resolve.all', size: 'default', className: `${merge_editor_module_less_1.default.merge_conflict_bottom_btn} ${merge_editor_module_less_1.default.magic_btn}`, onClick: handleAIResolve }, isAIResolving ? (react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement(ide_components_1.Icon, { icon: 'circle-pause' }),
                react_1.default.createElement("span", null, (0, ide_core_browser_1.localize)('mergeEditor.conflict.ai.resolve.all.stop')))) : (react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement(ide_components_1.Icon, { icon: 'magic-wand' }),
                react_1.default.createElement("span", null, (0, ide_core_browser_1.localize)('mergeEditor.conflict.ai.resolve.all')))))))));
};
exports.MergeEditorFloatComponents = MergeEditorFloatComponents;
//# sourceMappingURL=MergeEditorFloatComponents.js.map