"use strict";
/** ******************************************************************************
 * Copyright (C) 2018 Ericsson and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextmateRegistry = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_common_1 = require("@opensumi/ide-core-common");
let TextmateRegistry = class TextmateRegistry {
    constructor() {
        this.scopeToProvider = new Map();
        this.languageToConfig = new Map();
        this.languageIdToScope = new Map();
    }
    // 将语法定义描述绑定到某一个Scope：source.json.comments
    registerTextmateGrammarScope(scope, description) {
        if (this.scopeToProvider.has(scope)) {
            (0, ide_core_common_1.getDebugLogger)().warn(new Error(`a registered grammar provider for '${scope}' scope is overridden`));
        }
        this.scopeToProvider.set(scope, description);
        return () => {
            this.scopeToProvider.delete(scope);
        };
    }
    getProvider(scope) {
        return this.scopeToProvider.get(scope);
    }
    mapLanguageIdToTextmateGrammar(languageId, scope) {
        const existingScope = this.getScope(languageId);
        if (typeof existingScope === 'string') {
            (0, ide_core_common_1.getDebugLogger)().warn(new Error(`'${languageId}' language is remapped from '${existingScope}' to '${scope}' scope`));
        }
        this.languageIdToScope.set(languageId, scope);
        return () => {
            this.languageIdToScope.delete(languageId);
        };
    }
    getScope(languageId) {
        return this.languageIdToScope.get(languageId);
    }
    getLanguageId(scope) {
        for (const key of this.languageIdToScope.keys()) {
            if (this.languageIdToScope.get(key) === scope) {
                return key;
            }
        }
        return undefined;
    }
    registerGrammarConfiguration(languageId, getConfig) {
        if (this.languageToConfig.has(languageId)) {
            // console.warn(new Error(`a registered grammar configuration for '${languageId}' language is overridden`));
        }
        this.languageToConfig.set(languageId, getConfig);
        return () => {
            this.languageToConfig.delete(languageId);
        };
    }
    getGrammarConfiguration(languageId) {
        return this.languageToConfig.get(languageId) || (() => ({}));
    }
};
TextmateRegistry = tslib_1.__decorate([
    (0, di_1.Injectable)()
], TextmateRegistry);
exports.TextmateRegistry = TextmateRegistry;
//# sourceMappingURL=textmate-registry.js.map